@@ -13,12 +13,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import sys
-import math
 import blockdiag.DiagramDraw
 from blockdiag.utils import XY
-from blockdiag import noderenderer
-from blockdiag.DiagramMetrics import DiagramMetrics
 
 
 class DiagramDraw(blockdiag.DiagramDraw.DiagramDraw):
@@ -136,24 +132,28 @@ class DiagramDraw(blockdiag.DiagramDraw.DiagramDraw):
         if network.display_label:
             m = self.metrics.network(network)
             self.drawer.textarea(m.textbox, network.display_label,
-                                 fill=network.textcolor, halign="right",
-                                 fontsize=self.metrics.fontsize_for(network))
+                                 self.metrics.font_for(network),
+                                 fill=network.textcolor, halign="right")
 
     def node(self, node, **kwargs):
         m = self.metrics
 
         for connector in m.node(node).connectors:
             self.draw_connector(connector)
+            if hasattr(connector, 'subject'):
+                network = connector.subject.network
+            else:
+                network = connector.network
 
-            if connector.network in node.address:
-                label = node.address[connector.network]
+            if network in node.address:
+                label = node.address[network]
                 self.drawer.textarea(connector.textbox, label,
+                                     self.metrics.font_for(node),
                                      fill=node.textcolor, halign="left")
 
         super(DiagramDraw, self).node(node, **kwargs)
 
     def draw_connector(self, connector):
-        m = self.metrics
         self.drawer.line(connector.line,
                          fill=connector.network.linecolor, jump=True)
 
@@ -161,8 +161,8 @@ class DiagramDraw(blockdiag.DiagramDraw.DiagramDraw):
         if group.label:
             m = self.metrics.cell(group)
             self.drawer.textarea(m.grouplabelbox, group.label,
-                                 valign='top', fill=group.textcolor,
-                                 fontsize=self.metrics.fontsize_for(group))
+                                 self.metrics.font_for(group),
+                                 valign='top', fill=group.textcolor)
 
 
 from DiagramMetrics import DiagramMetrics
