@@ -35,12 +35,8 @@ At the moment, the parser builds only a parse tree, not an abstract syntax tree
   [1]: http://www.graphviz.org/doc/info/lang.html
 '''
 
-import os
-import sys
 import codecs
 from re import MULTILINE, DOTALL
-from pprint import pformat
-from funcparserlib.util import pretty_tree
 from funcparserlib.lexer import make_tokenizer, Token, LexerError
 from funcparserlib.parser import (some, a, maybe, many, finished, skip,
     oneplus, forward_decl, NoParseError)
@@ -56,6 +52,7 @@ Node = namedtuple('Node', 'id attrs')
 Attr = namedtuple('Attr', 'name value')
 Edge = namedtuple('Edge', 'nodes attrs')
 Route = namedtuple('Route', 'nodes attrs')
+AttrPlugin = namedtuple('AttrPlugin', 'name attrs')
 AttrClass = namedtuple('AttrClass', 'name attrs')
 DefAttrs = namedtuple('DefAttrs', 'object attrs')
 
@@ -88,7 +85,6 @@ def parse(seq):
     unarg = lambda f: lambda args: f(*args)
     tokval = lambda x: x.value
     flatten = lambda list: sum(list, [])
-    node_flatten = lambda l: sum([[l[0]]] + list(l[1:]), [])
     n = lambda s: a(Token('Name', s)) >> tokval
     op = lambda s: a(Token('Op', s)) >> tokval
     op_ = lambda s: skip(op(s))
@@ -99,10 +95,6 @@ def parse(seq):
     make_route = lambda x, x2, xs, attrs: Route([x, x2] + xs, attrs)
 
     node_id = id  # + maybe(port)
-    node_list = (
-        node_id +
-        many(op_(',') + node_id)
-        >> node_flatten)
     a_list = (
         id +
         maybe(op_('=') + id) +
@@ -163,9 +155,15 @@ def parse(seq):
         node_id +
         attr_list
         >> unarg(AttrClass))
+    plugin_stmt = (
+        skip(n('plugin')) +
+        id +
+        attr_list
+        >> unarg(AttrPlugin))
     stmt = (
           network
         | class_stmt
+        | plugin_stmt
         | group
         | graph_attr
         | route
@@ -174,7 +172,7 @@ def parse(seq):
     )
     stmt_list = many(stmt + skip(maybe(op(';'))))
     graph = (
-        maybe(n('diagram')) +
+        maybe(n('diagram') | n('nwdiag')) +
         maybe(id) +
         op_('{') +
         stmt_list +
