@@ -13,8 +13,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import os
-import re
 from elements import *
 import diagparser
 from blockdiag.utils import XY
@@ -46,6 +44,8 @@ class DiagramTreeBuilder:
                 _rack = Rack()
                 self.diagram.racks.append(_rack)
                 self.instantiate(_rack, stmt)
+            elif isinstance(stmt, diagparser.AttrPlugin):
+                self.diagram.set_plugin(stmt.name, stmt.attrs)
 
 
 class DiagramLayoutManager:
