@@ -14,10 +14,10 @@
 #  limitations under the License.
 
 import os
-import codecs
 from docutils import nodes
 from docutils.parsers import rst
 from rackdiag import diagparser
+from rackdiag.elements import RackItem
 from rackdiag.builder import ScreenNodeBuilder
 from rackdiag.DiagramDraw import DiagramDraw
 from blockdiag.utils.rst import directives
@@ -77,6 +77,32 @@ class RackdiagDirective(directives.BlockdiagDirective):
 
         return image
 
+    def description_table(self, diagram):
+        nodes = diagram.traverse_nodes
+        widths = [25] + [50] * (len(RackItem.desctable) - 1)
+        headers = [RackItem.attrname[name] for name in RackItem.desctable]
+
+        descriptions = [n.to_desctable() for n in nodes()]
+        descriptions.sort(directives.cmp_node_number)
+
+        # records for total
+        total = ['-', 'Total'] + [''] * (len(RackItem.desctable) - 2)
+        total[2] = u"%dU" % sum(n.colheight for n in nodes()  if n.colheight)
+        total[3] = u"%.1fA" % sum(n.ampere for n in nodes()  if n.ampere)
+        total[4] = u"%.1fkg" % sum(n.weight for n in nodes()  if n.weight)
+        descriptions.append(total)
+
+        for i in range(len(headers) - 1, -1, -1):
+            if any(desc[i] for desc in descriptions):
+                pass
+            else:
+                widths.pop(i)
+                headers.pop(i)
+                for desc in descriptions:
+                    desc.pop(i)
+
+        return self._description_table(descriptions, widths, headers)
+
 
 def setup(**kwargs):
     global format, antialias, fontpath
